# Multiple-Kernel-k-Means-Clustering-with-Matrix-Induced-Regularization Python Implementation
Non-official python implementation for AAAI16：Multiple Kernel k-Means Clustering with Matrix-Induced Regularization

# Usage

## Installation
You can install the package through pip with:

```shell script
pip install mkkm_mr
```

## Using the module
You can see an example usage under [demo](./examples/demo.py)

## Development
The project is using [poetry](https://python-poetry.org/) for reliable development.

See poetry documentation on how to install the latest version for your system:

> https://python-poetry.org/docs

### Setup
After installing poetry, start an environment:

```shell script
poetry install
```

If you are using PyCharm you can use [this plugin](https://plugins.jetbrains.com/plugin/14307-poetry) for setting up interpreter.

### Testing
Tests are using standard `pytest` format. You can run them after the setup with:

```shell script
pytest
```
